@@ -122,7 +122,8 @@ void KABCResource::configure( WId windowId )
     emit status( Running,
                  i18nc( "@info:status", "Changing address book plugin configuration" ) );
     KRES::ConfigDialog dlg( 0, QLatin1String( "contact" ), mBaseResource );
-    KWindowSystem::setMainWindow( &dlg, windowId );
+    if( windowId )
+      KWindowSystem::setMainWindow( &dlg, windowId );
     if ( dlg.exec() ) {
       setName( mBaseResource->resourceName() );
       manager->writeConfig( KGlobal::config().data() );
@@ -573,12 +574,13 @@ bool KABCResource::openConfiguration()
                  SIGNAL( signalSubresourceChanged( KABC::ResourceABC*, const QString&, const QString& ) ),
                  this, SLOT( subResourceChanged( KABC::ResourceABC*, const QString&, const QString& ) ) );
     }
-  }
+
 
   // do not react on addressbook changes until we have finished its initial loading
   mAddressBook->blockSignals( true );
 
   setName( mBaseResource->resourceName() );
+  }
 
   return true;
 }
@@ -699,6 +701,8 @@ void KABCResource::addressBookChanged()
 void KABCResource::subResourceAdded( KABC::ResourceABC *resource,
         const QString &type, const QString &subResource )
 {
+  Q_UNUSED( resource );
+  Q_UNUSED( type );
   kDebug() << "subResource" << subResource;
   Q_ASSERT( resource == mFolderResource );
   Q_ASSERT( type.toLower() == QLatin1String( "contact" ) );
@@ -712,6 +716,8 @@ void KABCResource::subResourceAdded( KABC::ResourceABC *resource,
 void KABCResource::subResourceRemoved( KABC::ResourceABC *resource,
         const QString &type, const QString &subResource )
 {
+  Q_UNUSED( resource );
+  Q_UNUSED( type );
   kDebug() << "subResource" << subResource;
   Q_ASSERT( resource == mFolderResource );
   Q_ASSERT( type.toLower() == QLatin1String( "contact" ) );
@@ -725,6 +731,8 @@ void KABCResource::subResourceRemoved( KABC::ResourceABC *resource,
 void KABCResource::subResourceChanged( KABC::ResourceABC *resource,
         const QString &type, const QString &subResource )
 {
+  Q_UNUSED( resource );
+  Q_UNUSED( type );
   kDebug() << "subResource" << subResource;
   Q_ASSERT( resource == mFolderResource );
   Q_ASSERT( type.toLower() == QLatin1String( "contact" ) );
@@ -848,9 +856,9 @@ KABC::ContactGroup KABCResource::contactGroupFromDistList( const KABC::Distribut
   KABC::ContactGroup contactGroup( list->name() );
   contactGroup.setId( list->identifier() );
 
-  KABC::DistributionList::Entry::List entries = list->entries();
+  const KABC::DistributionList::Entry::List entries = list->entries();
   foreach ( const KABC::DistributionList::Entry &entry, entries ) {
-    KABC::Addressee addressee = entry.addressee();
+    const KABC::Addressee addressee = entry.addressee();
     const QString email = entry.email();
     if ( addressee.isEmpty() ) {
       if ( email.isEmpty() )
@@ -859,7 +867,7 @@ KABC::ContactGroup KABCResource::contactGroupFromDistList( const KABC::Distribut
       KABC::ContactGroup::Data data( email, email );
       contactGroup.append( data );
     } else {
-      KABC::Addressee baseAddressee = mBaseResource->findByUid( addressee.uid() );
+      const KABC::Addressee baseAddressee = mBaseResource->findByUid( addressee.uid() );
       if ( baseAddressee.isEmpty() ) {
         KABC::ContactGroup::Data data( email, email );
         // TODO: transer custom fields?
