@@ -232,14 +232,21 @@ void AccountDialog::loadSettings()
 
   mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
                                 Wallet::Asynchronous );
-  connect( mWallet, SIGNAL(walletOpened(bool)),
-           this, SLOT(walletOpenedForLoading(bool)) );
+  if ( mWallet ) {
+    connect( mWallet, SIGNAL(walletOpened(bool)),
+             this, SLOT(walletOpenedForLoading(bool)) );
+  }
   passwordEdit->setEnabled( false );
+  passwordLabel->setEnabled( false );
 }
 
 void AccountDialog::walletOpenedForLoading( bool success )
 {
   if ( success ) {
+    if ( mWallet->isOpen() ) {
+      passwordEdit->setEnabled( true );
+      passwordLabel->setEnabled( true );
+    }
     if ( mWallet && mWallet->isOpen() && mWallet->hasFolder( "pop3" ) ) {
       QString password;
       mWallet->setFolder( "pop3" );
@@ -254,8 +261,6 @@ void AccountDialog::walletOpenedForLoading( bool success )
   else {
     kWarning() << "Failed to open wallet for loading the password.";
   }
-
-  passwordEdit->setEnabled( true );
 }
 
 void AccountDialog::walletOpenedForSaving( bool success )
@@ -279,7 +284,6 @@ void AccountDialog::walletOpenedForSaving( bool success )
       }
 
       mParentResource->clearCachedPassword();
-      Settings::self()->setStorePassword( !passwordEdit->text().isEmpty() );
     }
     else {
       kWarning() << "Wallet not open.";
@@ -610,12 +614,15 @@ void AccountDialog::saveSettings()
       kDebug() << "we need to open the wallet";
       mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
                                     Wallet::Asynchronous );
-      connect( mWallet, SIGNAL(walletOpened(bool)),
-              this, SLOT(walletOpenedForSaving(bool)) );
+      if ( mWallet ) {
+        connect( mWallet, SIGNAL(walletOpened(bool)),
+                this, SLOT(walletOpenedForSaving(bool)) );
+      } else {
+        accept();
+      }
     }
   }
   else {
-    // Neither save nor delete the password, we're done!
     accept();
   }
 }
