@@ -178,7 +178,6 @@ void POP3Resource::walletOpenedForSaving( bool success )
       }
       mWallet->setFolder( "pop3" );
       mWallet->writePassword( identifier(), mPassword );
-      Settings::self()->setStorePassword( true );
     }
   }
   else
@@ -193,10 +192,9 @@ void POP3Resource::walletOpenedForSaving( bool success )
 void POP3Resource::showPasswordDialog( const QString &queryText )
 {
   // FIXME: give this a proper parent widget
-  KPasswordDialog dlg( 0, KPasswordDialog::ShowUsernameLine | KPasswordDialog::ShowKeepPassword );
+  KPasswordDialog dlg( 0, KPasswordDialog::ShowUsernameLine );
   dlg.setUsername( Settings::self()->login() );
   dlg.setPassword( mPassword );
-  dlg.setKeepPassword( Settings::self()->storePassword() );
   dlg.setPrompt( queryText );
   dlg.setCaption( name() );
   dlg.addCommentLine( i18n( "Account:" ), name() );
@@ -208,11 +206,7 @@ void POP3Resource::showPasswordDialog( const QString &queryText )
     mPassword = dlg.password();
     Settings::self()->setLogin( dlg.username() );
     Settings::self()->writeConfig();
-    Settings::self()->setStorePassword( false );
-    if ( dlg.keepPassword() ) {
-      // setStorePassword( true ) is called only after the password is written into
-      // the wallet, as otherwise, the resource thinks the password is in the wallet
-      // and loads an empty password from it
+    if ( !dlg.password().isEmpty()  ) {
       mSavePassword = true;
     }
 
@@ -286,11 +280,13 @@ void POP3Resource::doStateStep()
       }
 
       const bool passwordNeeded = Settings::self()->authenticationMethod() != MailTransport::Transport::EnumAuthenticationType::GSSAPI;
-      const bool loadPasswordFromWallet = Settings::self()->storePassword() && !mAskAgain &&
-                                passwordNeeded && !Settings::self()->login().isEmpty() && mPassword.isEmpty();
+      const bool loadPasswordFromWallet = !mAskAgain && passwordNeeded && !Settings::self()->login().isEmpty() &&
+                                          mPassword.isEmpty();
       if ( loadPasswordFromWallet ) {
         mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winIdForDialogs(),
                                       Wallet::Asynchronous );
+      }
+      if ( loadPasswordFromWallet && mWallet ) {
         connect( mWallet, SIGNAL(walletOpened(bool)),
                  this, SLOT(walletOpenedForLoading(bool)) );
       }
@@ -300,7 +296,7 @@ void POP3Resource::doStateStep()
           detail = i18n( "You are asked here because the previous login was not successful." );
         else if ( Settings::self()->login().isEmpty() )
           detail = i18n( "You are asked here because the username you supplied is empty." );
-        else if ( !Settings::self()->storePassword() )
+        else if ( !mWallet )
           detail = i18n( "You are asked here because you choose to not store the password in the wallet." );
 
         showPasswordDialog( buildLabelForPasswordDialog( detail ) );
@@ -364,7 +360,7 @@ void POP3Resource::doStateStep()
       const QList<QString> alreadyDownloadedUIDs = Settings::self()->seenUidList();
       foreach( const QString &uidOnServer, UIDsOnServer ) {
         if ( alreadyDownloadedUIDs.contains( uidOnServer ) ) {
-          const int idOfUIDOnServer = mIdsToUidsMap.key( uidOnServer, -1 );
+          const int idOfUIDOnServer = mUidsToIdsMap.value( uidOnServer, -1 );
           Q_ASSERT( idOfUIDOnServer != -1 );
           idsToDownload.removeAll( idOfUIDOnServer );
         }
@@ -440,8 +436,12 @@ void POP3Resource::doStateStep()
         emit status( Running, i18n( "Saving password to the wallet." ) );
         mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winIdForDialogs(),
                                       Wallet::Asynchronous );
-        connect( mWallet, SIGNAL(walletOpened(bool)),
-                 this, SLOT(walletOpenedForSaving(bool)) );
+        if ( mWallet ) {
+          connect( mWallet, SIGNAL(walletOpened(bool)),
+                   this, SLOT(walletOpenedForSaving(bool)) );
+        } else {
+          finish();
+        }
       }
       break;
     }
@@ -515,11 +515,10 @@ void POP3Resource::loginJobResult( KJob *job )
 {
   if ( job->error() ) {
     kDebug() << job->error() << job->errorText();
-    if ( job->error() == KIO::ERR_COULD_NOT_LOGIN && !Settings::self()->storePassword() )
-        mAskAgain = true;
-    const QString errorString = i18n( "Unable to login to the server %1.", Settings::self()->host() ) + '\n' + job->errorString();
-    cancelSync( errorString );
-    KMessageBox::sorry( 0, errorString );
+    if ( job->error() == KIO::ERR_COULD_NOT_LOGIN )
+      mAskAgain = true;
+    cancelSync( i18n( "Unable to login to the server %1.", Settings::self()->host() ) +
+                '\n' + job->errorString() );
   }
   else {
     advanceState( List );
@@ -551,7 +550,9 @@ void POP3Resource::uidListJobResult( KJob *job )
     UIDListJob *listJob = dynamic_cast<UIDListJob*>( job );
     Q_ASSERT( listJob );
     mIdsToUidsMap = listJob->uidList();
+    mUidsToIdsMap = listJob->idList();
     kDebug() << "IdToUidMap:" << mIdsToUidsMap;
+    kDebug() << "UidToIdMap:" << mUidsToIdsMap;
 
     mUidListValid = !mIdsToUidsMap.isEmpty() || mIdsToSizeMap.isEmpty();
     if ( Settings::self()->leaveOnServer() && !mUidListValid ) {
@@ -631,7 +632,7 @@ void POP3Resource::messageDownloadProgress( KJob *job, KJob::Unit unit, qulonglo
   const int totalMessages = mIdsToDownload.size() + mDownloadedIDs.size();
   int bytesRemainingOnServer = 0;
   foreach( const QString &alreadyDownloadedUID, Settings::self()->seenUidList() ) {
-    const int alreadyDownloadedID = mIdsToUidsMap.key( alreadyDownloadedUID, -1 );
+    const int alreadyDownloadedID = mUidsToIdsMap.value( alreadyDownloadedUID, -1 );
     if ( alreadyDownloadedID != -1 )
       bytesRemainingOnServer += mIdsToSizeMap.value( alreadyDownloadedID );
   }
@@ -903,7 +904,7 @@ void POP3Resource::saveSeenUIDList()
     QList<int>::iterator timeIt = timeOfSeenUIDs.begin();
     while ( uidIt != seenUIDs.end() ) {
       const QString curSeenUID = *uidIt;
-      if ( !mIdsToUidsMap.values().contains( curSeenUID ) ) {
+      if ( !mUidsToIdsMap.contains( curSeenUID ) ) {
         // Ok, we have a UID in the seen UID list that is not anymore on the server.
         // Therefore remove it from the seen UID list, it is not needed there anymore,
         // it just wastes space.
@@ -950,6 +951,7 @@ void POP3Resource::resetState()
   mTargetCollection = Collection( -1 );
   mIdsToSizeMap.clear();
   mIdsToUidsMap.clear();
+  mUidsToIdsMap.clear();
   mDownloadedIDs.clear();
   mIdsToDownload.clear();
   mPendingCreateJobs.clear();
