@@ -154,6 +154,11 @@ class SingleFileResource : public SingleFileResourceBase
       }
     }
 
+    void writeFile( const QVariant &task_context )
+    {
+      writeFile( task_context.canConvert<bool>() && task_context.toBool() );
+    }
+
     /**
      * Write changes to the backend file.
      */
@@ -297,7 +302,6 @@ class SingleFileResource : public SingleFileResourceBase
       c.setRemoteId( mSettings->path() );
       const QString display = mSettings->displayName();
       c.setName( display.isEmpty() ? identifier() : display );
-      QStringList mimeTypes;
       c.setContentMimeTypes( mSupportedMimetypes );
       if ( readOnly() ) {
         c.setRights( Collection::CanChangeCollection );
